@@ -1,4 +1,4 @@
-//@line 42 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 42 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
 
 //******** define a js object to implement nsITreeView
 function pageInfoTreeView(copycol)
@@ -572,7 +572,7 @@ function grabAll(elem)
   if (elem instanceof HTMLImageElement)
     addImage(elem.src, gStrings.mediaImg,
              (elem.hasAttribute("alt")) ? elem.alt : gStrings.notSet, elem, false);
-//@line 616 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 616 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
   else if (elem instanceof SVGImageElement) {
     try {
       // Note: makeURLAbsolute will throw if either the baseURI is not a valid URI
@@ -581,7 +581,7 @@ function grabAll(elem)
       addImage(href, gStrings.mediaImg, "", elem, false);
     } catch (e) { }
   }
-//@line 625 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 625 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
   else if (elem instanceof HTMLLinkElement) {
     if (elem.rel && /\bicon\b/i.test(elem.rel))
       addImage(elem.href, gStrings.mediaLink, "", elem, false);
@@ -778,9 +778,9 @@ function makePreview(row)
 
   var imageText;
   if (!isBG &&
-//@line 822 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 822 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
       !(item instanceof SVGImageElement) &&
-//@line 824 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 824 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
       !(gDocument instanceof ImageDocument)) {
     imageText = item.title || item.alt;
 
@@ -874,9 +874,9 @@ function makePreview(row)
 
   if ((item instanceof HTMLLinkElement || item instanceof HTMLInputElement ||
        item instanceof HTMLImageElement ||
-//@line 918 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 918 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
        item instanceof SVGImageElement ||
-//@line 920 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 920 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
       (item instanceof HTMLObjectElement && /^image\//.test(mimeType)) || isBG) && isProtocolAllowed) {
     newImage.setAttribute("src", url);
     physWidth = newImage.width || 0;
@@ -896,12 +896,12 @@ function makePreview(row)
       newImage.height = newImage.naturalHeight;
     }
 
-//@line 940 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 940 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
     if (item instanceof SVGImageElement) {
       newImage.width = item.width.baseVal.value;
       newImage.height = item.height.baseVal.value;
     }
-//@line 945 "/builds/moz2_slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
+//@line 945 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/base/content/pageinfo/pageInfo.js"
 
     width = newImage.width;
     height = newImage.height;
@@ -1132,7 +1132,8 @@ function selectImage() {
 
   var tree = document.getElementById("imagetree");
   for (var i = 0; i < tree.view.rowCount; i++) {
-    if (gImageElement == gImageView.data[i][COL_IMAGE_NODE]) {
+    if (gImageElement == gImageView.data[i][COL_IMAGE_NODE] &&
+        !gImageView.data[i][COL_IMAGE_BG]) {
       tree.view.selection.select(i);
       tree.treeBoxObject.ensureRowIsVisible(i);
       tree.focus();
